"""Declares :class:`IResource`."""
import resource
import typing

import fastapi
import pydantic

from cbra.lib.auth import IPrincipal
from cbra.resource.resourceoptions import ResourceOptions


ReturnTypes = typing.Union[
    fastapi.Response,
    pydantic.BaseModel
]


class IResource:
    meta: ResourceOptions
    method: str
    path: str
    principal: typing.Optional[IPrincipal]
    request: fastapi.Request
    resource_class: typing.Type[pydantic.BaseModel]
    response: fastapi.Response
    ReturnTypes: typing.Any = ReturnTypes

    def setup_request_context(
        self,
        method: str,
        path: str,
        request: fastapi.Request,
        response: fastapi.Response,
        principal: typing.Optional[IPrincipal] = None
    ) -> None:
        """Invoked prior to running the request handler."""
        self.method = method
        self.path = path
        self.principal = principal
        self.request = request
        self.response = response

    async def dispatch(
        self,
        handle: typing.Callable[..., ReturnTypes]
    ) -> ReturnTypes:
        raise NotImplementedError

    def update_envelope(
        self,
        request: fastapi.Request,
        result: ReturnTypes,
        handler: object
    ) -> None:
        raise NotImplementedError