# pylint: skip-file
import pydantic
import pytest

import cbra


class SubresourceClass(pydantic.BaseModel):
    child_id: int

    class Config:
        path_parameter: int = 'child_id'


class ResourceClass(pydantic.BaseModel):
    object_id: int
    foo: int

    class Config:
        path_parameter: int = 'object_id'


class EnvelopedSubresource(cbra.resource.PublicResource):
    resource_class = SubresourceClass

    async def list(self):
        return [{
            'child_id': 1,
        }]

    class Meta:
        path_parameter: int = 'child_id'
        name = 'child'
        pluralname = 'children'


class EnvelopedResource(cbra.resource.PublicResource):
    resource_class = ResourceClass
    subresources = [EnvelopedSubresource]

    async def list(self):
        return [{
            'object_id': 1,
            'foo': 1
        }]

    async def retrieve(self, object_id: int):
        return {
            'object_id': object_id,
            'foo': 1
        }

    class Meta:
        path_parameter: int = 'object_id'
        name = 'object'
        pluralname = 'objects'


@pytest.fixture
def app():
    app = cbra.Application()
    EnvelopedResource.add_to_router(app, '')
    return app
