# pylint: skip-file
import inspect
import itertools
import typing
from inspect import Parameter

from .mediatypes import media_type_matches


__all__ = [
	'media_type_matches',
    'normalize_signature'
]


def order_parameters(params: typing.List[Parameter]) -> typing.List[Parameter]:
    """Take a list of parameters and ensure that they are ordered correctly i.e.
    positional arguments, keyword arguments, variable positional arguments and
    variable keyword arguments.
    """
    return itertools.chain(
        [x for x in params if x .kind == Parameter.POSITIONAL_ONLY],
        [x for x in params if x .kind == Parameter.POSITIONAL_OR_KEYWORD],
        [x for x in params if x .kind == Parameter.VAR_POSITIONAL],
        [x for x in params if x .kind == Parameter.KEYWORD_ONLY],
        [x for x in params if x .kind == Parameter.VAR_KEYWORD],
    )


def normalize_signature(func):
    """Normalize the signature of a function or method so that it
    can be used as a :mod:`fastapi` request handler.
    """
    sig = inspect.signature(func)
    func.__signature__ = sig.replace(
        parameters=[
            x for x in sig.parameters.values()
            if x.name != 'self'
        ]
    )
    return func


class PositionalArgument(inspect.Parameter):

    def __init__(self,
        name: str,
        annotation: type = None,
        **kwargs
    ):
        super().__init__(
            name=name,
            kind=Parameter.POSITIONAL_ONLY,
            annotation=annotation,
            **kwargs
        )
