# pylint: skip-file
import base64

import aorta
import fastapi
import uvicorn
from unimatrix.ext.kms import JSONWebToken

import cbra
from cbra.lib.auth import NullJWTPrincipal
from cbra.ext.google import AortaEventarcReceiver


class ExampleCommand(aorta.Command):
    foo: int
    bar: int
    baz: int = None


class ExampleCommandHandler(aorta.CommandHandler):

    async def handle(self, fastapi: fastapi.Request):
        print(f"Running {type(self).__name__}")
        print(repr(self.args))


aorta.register(ExampleCommand, ExampleCommandHandler)

print(base64.b64encode(bytes(ExampleCommand(foo=1, bar=2).as_message())))

app = cbra.Application(log_exceptions=True)
app.add(
    AortaEventarcReceiver(
        members=["foo@bar.baz"],
        principal_class=lambda *a, **k: NullJWTPrincipal(
            aud="http://127.0.0.1:8000",
            sub="foo",
            email="foo@bar.baz"
        ),
    ),
    path='/eventarc'
)


if __name__ == '__main__':
    uvicorn.run(app)

