# pylint: skip-file
import base64

import aorta
import fastapi
import ioc
import uvicorn
from unimatrix.ext.kms import JSONWebToken

import cbra
from cbra.lib.auth import NullJWTPrincipal
from cbra.ext.google import AortaEventarcReceiver
from cbra.ext.google import DebugTransport


class ExampleCommand(aorta.Command):
    foo: int
    bar: int
    baz: int = None


class ExampleCommandHandler(aorta.CommandHandler):

    async def handle(self, fastapi: fastapi.Request):
        pass


aorta.register(ExampleCommand, ExampleCommandHandler)

app = cbra.Application(log_exceptions=True)
app.add(
    AortaEventarcReceiver(
        members=["foo@bar.baz"],
        principal_class=lambda *a, **k: NullJWTPrincipal(
            aud="http://127.0.0.1:8000",
            sub="foo",
            email="foo@bar.baz"
        ),
    ),
    path='/eventarc'
)

ioc.provide('MessagePublisher',
    aorta.MessagePublisher(
        transport=DebugTransport(app, "http://127.0.0.1:8000", "/eventarc")
    ),
    force=True
)


@app.post('/publish')
async def publish_message():
    publisher = ioc.require('MessagePublisher')
    await publisher.publish(ExampleCommand(foo=1, bar=2))


if __name__ == '__main__':
    uvicorn.run(app)


