# pylint: skip-file
import cbra
import pydantic
import uvicorn


class Author(pydantic.BaseModel):
    name: str


class Book(pydantic.BaseModel):
    id: int
    title: str
    author: Author

    class Config:
        path_parameter: str = 'id'


class RelatedBookResource(cbra.PublicResource):
    resource_class = Book

    async def list(self, book_id: int):
        return []

    class Meta:
        name = 'suggestion'
        path_parameter = 'suggestion_id'


class BookResource(cbra.PublicResource):
    resource_class = Book
    subresources = [RelatedBookResource]
    books = {
        1: {
            "id": 1,
            "title": "Voyage au centre de la terre",
            "author": {
                "name": "Jules Verne"
            }
        },
        2: {
            "id": 2,
            "title": "Le tour du monde en quatre-vingts jours",
            "author": {
                "name": "Jules Verne"
            }
        }
    }

    async def list(self):
        return list(sorted(self.books.values(), key=lambda x: x['id']))

    async def retrieve(self, book_id: int):
        return self.books[book_id]

    class Meta:
        name = 'book'
        path_parameter = 'book_id'


app = cbra.Application()
app.add(BookResource)


if __name__ == '__main__':
    uvicorn.run('__main__:app', reload=True)

    # Run curl http://localhost:8000/books/1 | python3 -m json.tool
    # and see for yourself!
