"""Demonstrates how to create query for request URIs using class-based
endpoints.
"""
import typing

import cbra
import pydantic
import uvicorn


class ExampleQuery(cbra.query.RequestQuery):
    name: typing.Optional[str] = pydantic.Field(...,
        title="Name",
        description="Filter the search query by the `name` attribute."
    )

    status: str = None


class ExampleResource(cbra.PublicResource):

    async def list(self, query=ExampleQuery(run=False)):
        return query.dict()

    class Meta:
        name = 'example'
        path_parameter = 'object_id'


app = cbra.Application()
app.add(ExampleResource)


if __name__ == '__main__':
    uvicorn.run('__main__:app', reload=True)
